@@ -133,8 +133,8 @@ class BaseDataManager(object):
         return {'links': links}
 
     def generate(self, filename: str, fields: Optional[list] = None) -> dict:
-        fields: list = fields if fields else self.get_default_serializer_fields()
-        return self._generate_result(filename=filename, fields=fields)
+        fields_list: list = fields if fields else self.get_default_serializer_fields()
+        return self._generate_result(filename=filename, fields=fields_list)
 
 
 class BaseStatisticSelector(object):
@@ -155,7 +155,7 @@ class BaseStatisticSelector(object):
         self.platform_id = platform_id
         self.values = values
 
-    def get_date_params(self) -> any:
+    def get_date_params(self) -> Any:
         date_from = None
         date_to = None
         if self.data.get("last_week", "").lower() == 'true':
@@ -201,6 +201,7 @@ class BaseStatisticSelector(object):
         date_from, date_to = self.get_date_params()
         filename = self.generate_file_name(date_from=date_from, date_to=date_to)
         return self.generate_statistic_response(
-            date_from=date_from, date_to=date_to, filename=filename,
+            date_from=date_from,
+            date_to=date_to,
+            filename=filename,
         )
-
