@@ -29,26 +29,6 @@ class BaseCredentialModelViewSet(CredentialMixin, ModelViewSet):
     def create(self, request, format=None):
         raise NotImplementedError()
 
-    def retrieve(self, request, *args, **kwargs):
-        """
-        ---
-        parameters:
-            - Authorization token in headers
-        """
-
-        _ = self.get_check_dash_auth(request)
-        return super().retrieve(request, *args, **kwargs)
-
-    def list(self, request, *args, **kwargs):
-        """
-        ---
-        parameters:
-            - Authorization token in headers
-        """
-        _ = self.get_check_dash_auth(request)
-
-        return super().list(request, *args, **kwargs)
-
 
 # base View model
 class BaseReportListAPIView(LimitOffsetPaginationListAPIView):
